@@ -7,6 +7,7 @@
 import os
 import stat
 import sys
+import shlex
 from functools import partial
 from inspect import signature
 from typing import Optional
@@ -14,6 +15,7 @@ from typing import Optional
 import portage
 from portage.dep import Atom, use_reduce
 from portage.dep._slot_operator import strip_slots
+from portage.dep.libc import find_libc_deps, strip_libc_deps
 
 import gentoolkit.pprinter as pp
 from gentoolkit.eclean.exclude import (
@@ -134,6 +136,7 @@ class DistfilesSearch:
         # gather the files to be cleaned
         self.output("...checking limits for %d ebuild sources" % len(pkgs))
 
+        vcs = self.vcs_check(_distdir)
         checks = self._get_default_checks(size_limit, time_limit, exclude, destructive)
         checks.extend(extra_checks)
         clean_me = self._check_limits(_distdir, checks, clean_me)
@@ -148,7 +151,7 @@ class DistfilesSearch:
                 + "%s remaining candidates to clean" % len(clean_me)
             )
             clean_me, saved = self._check_excludes(exclude, clean_me)
-        return clean_me, saved, deprecated
+        return clean_me, saved, deprecated, vcs
 
     # begin _check_limits code block
 
@@ -332,6 +335,33 @@ class DistfilesSearch:
             deprecated.update(_deprecated)
         return pkgs, deprecated
 
+    def vcs_check(self, distdir):
+        """Checks $DISTDIR/vcs-src for checkouts which are not in the vardb"""
+        # For now we only check git
+        vcs_src = os.path.join(distdir, "git3-src")
+        if not os.path.exists(vcs_src):
+            return {}
+
+        expected_dirs = set()
+        for i in set(self.vardb.cpv_all()):
+            if "live" in self.vardb.aux_get(i, ["PROPERTIES"]):
+                try:
+                    # try to get the dir names of the cloned
+                    # repos from the environment file.
+                    vcs_dir = {
+                        i.split("=")[-1].strip('"')
+                        for i in shlex.split(
+                            self.vardb._aux_env_search(i, ["EVCS_STORE_DIRS"])[
+                                "EVCS_STORE_DIRS"
+                            ].strip("()")
+                        )
+                    }
+                    expected_dirs.update(vcs_dir)
+                except KeyError:
+                    pass
+        actual_dirs = {os.path.join(vcs_src, i) for i in os.listdir(vcs_src)}
+        return actual_dirs.difference(expected_dirs)
+
     def _fetch_restricted(self, pkgs_, cpvs):
         """perform fetch restricted non-destructive source
         filename lookups
@@ -496,13 +526,15 @@ class DistfilesSearch:
         return clean_me, saved
 
 
-def _deps_equal(deps_a, eapi_a, deps_b, eapi_b, uselist=None):
+def _deps_equal(deps_a, eapi_a, deps_b, eapi_b, libc_deps, uselist=None):
     """Compare two dependency lists given a set of USE flags"""
     if deps_a == deps_b:
         return True
 
     deps_a = use_reduce(deps_a, uselist=uselist, eapi=eapi_a, token_class=Atom)
     deps_b = use_reduce(deps_b, uselist=uselist, eapi=eapi_b, token_class=Atom)
+    strip_libc_deps(deps_a, libc_deps)
+    strip_libc_deps(deps_b, libc_deps)
     strip_slots(deps_a)
     strip_slots(deps_b)
     return deps_a == deps_b
@@ -557,6 +589,8 @@ def findPackages(
         print(pp.error("Error: %s" % str(er)), file=sys.stderr)
         exit(1)
 
+    libc_deps = find_libc_deps(var_dbapi, False)
+
     # Create a dictionary of all installed packages
     if destructive and package_names:
         installed = dict.fromkeys(var_dbapi.cp_all())
@@ -627,6 +661,7 @@ def findPackages(
                 binpkg_metadata["EAPI"],
                 " ".join(ebuild_metadata[key] for key in dep_keys),
                 ebuild_metadata["EAPI"],
+                libc_deps,
                 frozenset(binpkg_metadata["USE"].split()),
             ):
                 continue
